@@ -1,10 +1,12 @@
 #include "alternatives.ih"
 
+    // by findalternatives.cc
+
 void Alternatives::setIgnored()
 {
     for                                 // add all ignored dirs in the 
     (                                   // config file
-        auto iters = Options::instance().ignore();
+        auto iters = d_options.ignore();
         string const &line: ranger(iters.first, iters.second)
     )
         addIgnored(line);               // add line's path to d_ignored
