@@ -17,6 +17,8 @@
 // d_arguments contains the individual args, ending in /.
 // E.g., 2abc -> abc/, 2 ab cd de -> ab/cd/de/
 
+class Options;
+
 struct Command: public std::vector<std::string>
                        // stores the elements of the pattern
 {
@@ -31,6 +33,7 @@ struct Command: public std::vector<std::string>
     };
 
     private:
+        Options const &d_options;
         Action d_action;
         size_t d_parent;
 
@@ -44,9 +47,9 @@ struct Command: public std::vector<std::string>
     public:
         Command();
 
-        std::string const &accumulate() const;  // d_arguments
-        size_t parent() const;                  // FROM_PARENT number
-        Action action() const;                  // Action type
+        std::string const &accumulate() const;  // d_arguments              .f
+        size_t parent() const;                  // FROM_PARENT number       .f
+        Action action() const;                  // Action type              .f
 
     private:
         void concatArgs();
@@ -55,20 +58,6 @@ struct Command: public std::vector<std::string>
                                             // separate vector elements
 };
 
-inline size_t Command::parent() const
-{
-    return d_parent;
-}
-
-inline Command::Action Command::action() const
-{
-    return d_action;
-}
-
-inline std::string const &Command::accumulate() const
-{
-    return d_arguments;
-}
-
+#include "command.f"
 
 #endif
