@@ -1,10 +1,13 @@
 #include "command.ih"
 
+    // by alternatives/alternatives1.cc (implicitly)
+
 Command::Command()
 :
+    d_options(Options::instance()),
     d_action(FROM_HOME),
     d_parent(0),
-    d_homedirChar(Options::instance().homedirChar())
+    d_homedirChar(d_options.homedirChar())
 {
     imsg << "\n"
             "Command\n";
