@@ -1,8 +1,10 @@
 #include "command.ih"
 
+    // by command1.cc
+
 void Command::concatArgs()
 {
-    auto ranger = Options::instance().args();
+    auto ranger = d_options.args();
 
     for (char const *arg: ranger)               // all arguments end in /
         (d_arguments += arg) += '/';
