@@ -38,18 +38,18 @@ class History
     public:
         History();
 
-        Position position() const;
-
-        void setLocation(size_t nInHistory);
-        void save(std::string const &choice);
-        bool rotate() const;
-
                                         // see if a path is in the history
-        bool find(std::string const &path) const;
+        bool find(std::string const &path) const;                       // .f
+
+        std::vector<HistoryInfo>::const_iterator findIter(              // .f
+                                            std::string const &path) const;
+
+        Position position() const;                                      // .f
+        bool rotate() const;                                            // .f
+
+        void save(std::string const &choice);
 
     private:
-        std::vector<HistoryInfo>::const_iterator findIter(
-                                            std::string const &path) const;
         void load();
 
         static void maybeInsert(HistoryInfo  const &historyInfo,
