@@ -11,17 +11,17 @@ namespace
         {"directories",         ArgConfig::Required},
         {"generalized-search",  'g'},
         {"help",                'h'},
-        {"input",               ArgConfig::None},
+        {"input",               ArgConfig::NoArg},
         {"history",             ArgConfig::Optional},
         {"history-lifetime",    ArgConfig::Required},
         {"history-maxsize",     ArgConfig::Required},   // history/load.cc
         {"history-position",    ArgConfig::Required},   // top, bottom
-        {"history-separate",    ArgConfig::None},
+        {"history-separate",    ArgConfig::NoArg},
         {"homedir-char",        ArgConfig::Required},
         {"icase",               'i'},
-        {"no-input",            ArgConfig::None},
+        {"no-input",            ArgConfig::NoArg},
         {"start-at",            ArgConfig::Required},
-        {"traditional",         ArgConfig::None},
+        {"traditional",         ArgConfig::NoArg},
         {"verbose",             'V'},
         {"version",             'v'},
     };
