@@ -1,96 +1,113 @@
+    // by alternatives/alternatives1.cc
 inline TriState Options::addRoot() const
 {
     return d_addRoot;
 }
 
+    // by alternatives/findalternatives.cc
 inline bool Options::all() const
 {
     return d_arg.option('a');
 }
 
+    // by alternatives/alternatives1.cc
 inline bool Options::allDirs() const
 {
     return d_allDirs;
 }
 
+    // by command/concatargs.cc
 inline FBB::Ranger<char const **> Options::args() const
 {
     return FBB::ranger(d_arg.argPointers(), d_arg.nArgs());
 }
 
+    // by selector/setblocksize.cc
 inline size_t Options::blockSize() const
 {
     return d_blockSize;
 }
 
-
+    // by alternatives/alternatives1.cc
 inline bool Options::fromHome() const
 {
     return d_fromHome;
 }
 
+    // by alternatives/finddirs.cc
 inline bool Options::generalized() const
 {
     return d_arg.option('g');
 }
 
-inline size_t Options::historyLifetime() const
-{
-    return d_historyLifetime;
-}
-
-inline size_t Options::historyMaxSize() const
-{
-    return d_historyMaxSize;
-}
-
+    // by history/history1.cc
 inline std::string const &Options::history() const
 {
     return d_history;
 }
 
+    // by history/load.cc
+inline size_t Options::historyLifetime() const
+{
+    return d_historyLifetime;
+}
+
+    // by history/save.cc
+inline size_t Options::historyMaxSize() const
+{
+    return d_historyMaxSize;
+}
+
+    // by alternatives/startdir.cc history/history1.cc
 inline std::string const &Options::homeDir() const
 {
     return d_homeDir;
 }
 
+    // by alternatives/checkcase.cc
 inline size_t Options::icase() const
 {
     return d_arg.option('i');
 }
 
+    // by alternatives/setignored.cc
+inline auto Options::ignore() const
+{
+    return d_arg.beginEndRE("^\\s*ignore\\s+\\S+\\s*$");
+}
+
+    // by ./noinput.cc selector/selector1.cc
 // static
 inline bool Options::input()
 {
     return s_input;
 }
 
-inline auto Options::ignore() const
-{
-    return d_arg.beginEndRE("^\\s*ignore\\s+\\S+\\s*$");
-}
-
+    // by history/history1.cc
 inline size_t Options::now() const
 {
     return d_now;
 }
 
+    // by history/history.f (position, rotate)
 inline Position Options::historyPosition() const
 {
     return d_historyPosition;
 }
 
+    // by alternatives/separateat.cc
 inline bool Options::separate() const
 {
     return d_separate;
 }
 
+    // by alternatives/finddirs.cc
 inline bool Options::traditional() const
 {
     return d_arg.option(0, "traditional");
 }
 
-
+    // by alternatives/viable.cc
 inline std::string const &Options::triStateStr() const
 {
     return s_triState[d_addRoot];
