@@ -5,6 +5,7 @@
 #include <string>
 #include <vector>
 
+class Options;
 class Alternatives;
 
 struct Selector
@@ -38,7 +39,8 @@ struct Selector
             size_t end;
             std::string prompt;
         };
-    
+
+        Options const &d_options;    
         Alternatives &d_alternatives;
     
         size_t d_index;                 // constructor: #alternatives,
@@ -61,7 +63,7 @@ struct Selector
         Selector(Alternatives &alternatives);
 
         void select();
-        ReturnValue returnValue() const;                    // .f
+        ReturnValue returnValue() const;                                // .f
 
     private:
         static bool accept(int ch, std::string const &alternatives, 
