@@ -1,10 +1,13 @@
 #include "selector.ih"
 
+    // by ./main.cc
+
 Selector::Selector(Alternatives &alternatives)
 :
+    d_options(Options::instance()),
     d_alternatives(alternatives),
     d_index(d_alternatives.size()),
-    d_ioctl(Options::instance().input()),
+    d_ioctl(d_options.input()),
     d_direct(d_alternatives.result() == DIRECT),
     d_returnValue(ERROR)
 {
