@@ -1,11 +1,13 @@
 #include "selector.ih"
 
+    // by selector1.cc
+
 void Selector::setBlockSize()
 {
                                     // blockSize cannot exceed the #available
                                     // selection chars or the #available 
                                     // alternatives
-    d_blockSize = Options::instance().blockSize();
+    d_blockSize = d_options.blockSize();
 
     if (d_blockSize  < MIN_BLOCK_SIZE)
         d_blockSize = MIN_BLOCK_SIZE;
